pm4py.objects.conversion.dfg.variants package
=============================================

Submodules
----------

pm4py.objects.conversion.dfg.variants.to\_petri\_net\_activity\_defines\_place module
-------------------------------------------------------------------------------------

.. automodule:: pm4py.objects.conversion.dfg.variants.to_petri_net_activity_defines_place
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.objects.conversion.dfg.variants.to\_petri\_net\_invisibles\_no\_duplicates module
---------------------------------------------------------------------------------------

.. automodule:: pm4py.objects.conversion.dfg.variants.to_petri_net_invisibles_no_duplicates
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.objects.conversion.dfg.variants
   :members:
   :undoc-members:
   :show-inheritance:
